==> apache-beam-2.37.0-source-release.zip: beam-2.37.0/playground/frontend/lib/constants/sizes.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// spacings
const double kZeroSpacing = 0.0;
const double kSmSpacing = 4.0;
const double kMdSpacing = 8.0;
const double kLgSpacing = 12.0;
const double kXlSpacing = 16.0;
const double kXxlSpacing = 36.0;

// sizes
const kHeaderButtonHeight = 46.0;
const kRunButtonWidth = 150.0;
const kButtonHeight = 40.0;
const kIconButtonSplashRadius = 24.0;
const kFooterHeight = 32.0;

// border radius
const double kSmBorderRadius = 4.0;
const double kMdBorderRadius = 6.0;
const double kLgBorderRadius = 8.0;
const double kXlBorderRadius = 28.0;

// elevation
const double kElevation = 2;

// icon sizes
const double kIconSizeXs = 8.0;
const double kIconSizeSm = 16.0;
const double kIconSizeMd = 24.0;
const double kIconSizeLg = 32.0;

// cursor size
const double kCursorSize = 1.0;

// container size
const double kContainerHeight = 40.0;

const double kCodeFontSize = 14.0;
const double kLabelFontSize = 16.0;
const double kHintFontSize = 16.0;
const double kTitleFontSize = 18.0;

//divider size
const double kDividerHeight = 1.0;
const double kLgDividerHeight = 2.0;

==> apache-beam-2.42.0-source-release.zip: beam-2.42.0/playground/frontend/lib/constants/sizes.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// spacings
const double kZeroSpacing = 0.0;
const double kSmSpacing = 4.0;
const double kMdSpacing = 8.0;
const double kLgSpacing = 12.0;
const double kXlSpacing = 16.0;
const double kXxlSpacing = 36.0;

// sizes
const kHeaderButtonHeight = 46.0;
const kRunButtonWidth = 150.0;
const kButtonHeight = 40.0;
const kIconButtonSplashRadius = 24.0;
const kFooterHeight = 32.0;

// border radius
const double kSmBorderRadius = 4.0;
const double kMdBorderRadius = 6.0;
const double kLgBorderRadius = 8.0;
const double kXlBorderRadius = 28.0;

// elevation
const double kElevation = 2;

// icon sizes
const double kIconSizeXs = 8.0;
const double kIconSizeSm = 16.0;
const double kIconSizeMd = 24.0;
const double kIconSizeLg = 32.0;

// cursor size
const double kCursorSize = 1.0;

// container size
const double kContainerHeight = 40.0;

const double kCaptionFontSize = 10.0;
const double kCodeFontSize = 14.0;
const double kLabelFontSize = 16.0;
const double kHintFontSize = 16.0;
const double kTitleFontSize = 18.0;

//divider size
const double kDividerHeight = 1.0;
const double kLgDividerHeight = 2.0;

//loading indicator size
const double kMdLoadingIndicatorSize = 40.0;
const double kLgLoadingIndicatorSize = 50.0;
